Andrea Arighi <andrea@chino.io>
Daniele Zanotelli <daniele@chino.io>
Stefano Tranquillini <stefano@chino.io>
Jovan Stevovic
Luca Degregori

- - -

*Add your info on the bottom of the list. Suggested format:*

    - name, [email,] [company]
